lab5group8-package: This package connects to the Kolada web-api and shows the...

Description Details Author(s) References

Description

The app shows bargraphs of the population of swedish municipalities over time. It allows the user to select the muncicipality and the time-window.

Details

The DESCRIPTION file: This package was not yet installed at build time.

Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most important functions ~~

Author(s)

c(person("Bayu Beta", "Brahmantio", email = "bayubrahmantio@gmail.com", role = c("aut", "cre")), person("Joris", "van Doorn", email = "jorva845@student.liu.se", role = "aut"))

Maintainer: Bayu Beta Brahmantio, <bayubrahmantio@gmail.com>

References

~~ Literature or other references for background information ~~


Jorisvdoorn/lab5group8 documentation built on Oct. 30, 2019, 8:02 p.m.