population-class: Population

Description Value

Description

Create an object containing population data of swedish municipalities. This function does not take any parameters but instead gets its data from the Kolada web-api.

Value

Returns an object of the class 'population'. This object can be manipulated.


Jorisvdoorn/lab5group8 documentation built on Oct. 30, 2019, 8:02 p.m.