Create an object containing population data of swedish municipalities. This function does not take any parameters but instead gets its data from the Kolada web-api.
Returns an object of the class 'population'. This object can be manipulated.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.